# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/services/geo_target_constant_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.resources import geo_target_constant_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_geo__target__constant__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/services/geo_target_constant_service.proto',
  package='google.ads.googleads.v1.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v1.servicesB\035GeoTargetConstantServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V1.Services\312\002 Google\\Ads\\GoogleAds\\V1\\Services\352\002$Google::Ads::GoogleAds::V1::Services'),
  serialized_pb=_b('\nHgoogle/ads/googleads_v1/proto/services/geo_target_constant_service.proto\x12 google.ads.googleads.v1.services\x1a\x41google/ads/googleads_v1/proto/resources/geo_target_constant.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\"4\n\x1bGetGeoTargetConstantRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\xe7\x03\n SuggestGeoTargetConstantsRequest\x12,\n\x06locale\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x63ountry_code\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12j\n\x0elocation_names\x18\x01 \x01(\x0b\x32P.google.ads.googleads.v1.services.SuggestGeoTargetConstantsRequest.LocationNamesH\x00\x12\x64\n\x0bgeo_targets\x18\x02 \x01(\x0b\x32M.google.ads.googleads.v1.services.SuggestGeoTargetConstantsRequest.GeoTargetsH\x00\x1a<\n\rLocationNames\x12+\n\x05names\x18\x01 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x1aH\n\nGeoTargets\x12:\n\x14geo_target_constants\x18\x01 \x03(\x0b\x32\x1c.google.protobuf.StringValueB\x07\n\x05query\"\x8b\x01\n!SuggestGeoTargetConstantsResponse\x12\x66\n\x1fgeo_target_constant_suggestions\x18\x01 \x03(\x0b\x32=.google.ads.googleads.v1.services.GeoTargetConstantSuggestion\"\xd8\x02\n\x1bGeoTargetConstantSuggestion\x12,\n\x06locale\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x05reach\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0bsearch_term\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Q\n\x13geo_target_constant\x18\x04 \x01(\x0b\x32\x34.google.ads.googleads.v1.resources.GeoTargetConstant\x12Y\n\x1bgeo_target_constant_parents\x18\x05 \x03(\x0b\x32\x34.google.ads.googleads.v1.resources.GeoTargetConstant2\xac\x03\n\x18GeoTargetConstantService\x12\xbd\x01\n\x14GetGeoTargetConstant\x12=.google.ads.googleads.v1.services.GetGeoTargetConstantRequest\x1a\x34.google.ads.googleads.v1.resources.GeoTargetConstant\"0\x82\xd3\xe4\x93\x02*\x12(/v1/{resource_name=geoTargetConstants/*}\x12\xcf\x01\n\x19SuggestGeoTargetConstants\x12\x42.google.ads.googleads.v1.services.SuggestGeoTargetConstantsRequest\x1a\x43.google.ads.googleads.v1.services.SuggestGeoTargetConstantsResponse\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/geoTargetConstants:suggest:\x01*B\x84\x02\n$com.google.ads.googleads.v1.servicesB\x1dGeoTargetConstantServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V1.Services\xca\x02 Google\\Ads\\GoogleAds\\V1\\Services\xea\x02$Google::Ads::GoogleAds::V1::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_geo__target__constant__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_GETGEOTARGETCONSTANTREQUEST = _descriptor.Descriptor(
  name='GetGeoTargetConstantRequest',
  full_name='google.ads.googleads.v1.services.GetGeoTargetConstantRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.GetGeoTargetConstantRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=291,
)


_SUGGESTGEOTARGETCONSTANTSREQUEST_LOCATIONNAMES = _descriptor.Descriptor(
  name='LocationNames',
  full_name='google.ads.googleads.v1.services.SuggestGeoTargetConstantsRequest.LocationNames',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='names', full_name='google.ads.googleads.v1.services.SuggestGeoTargetConstantsRequest.LocationNames.names', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=638,
  serialized_end=698,
)

_SUGGESTGEOTARGETCONSTANTSREQUEST_GEOTARGETS = _descriptor.Descriptor(
  name='GeoTargets',
  full_name='google.ads.googleads.v1.services.SuggestGeoTargetConstantsRequest.GeoTargets',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='geo_target_constants', full_name='google.ads.googleads.v1.services.SuggestGeoTargetConstantsRequest.GeoTargets.geo_target_constants', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=700,
  serialized_end=772,
)

_SUGGESTGEOTARGETCONSTANTSREQUEST = _descriptor.Descriptor(
  name='SuggestGeoTargetConstantsRequest',
  full_name='google.ads.googleads.v1.services.SuggestGeoTargetConstantsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='locale', full_name='google.ads.googleads.v1.services.SuggestGeoTargetConstantsRequest.locale', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country_code', full_name='google.ads.googleads.v1.services.SuggestGeoTargetConstantsRequest.country_code', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location_names', full_name='google.ads.googleads.v1.services.SuggestGeoTargetConstantsRequest.location_names', index=2,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_targets', full_name='google.ads.googleads.v1.services.SuggestGeoTargetConstantsRequest.geo_targets', index=3,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SUGGESTGEOTARGETCONSTANTSREQUEST_LOCATIONNAMES, _SUGGESTGEOTARGETCONSTANTSREQUEST_GEOTARGETS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='query', full_name='google.ads.googleads.v1.services.SuggestGeoTargetConstantsRequest.query',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=294,
  serialized_end=781,
)


_SUGGESTGEOTARGETCONSTANTSRESPONSE = _descriptor.Descriptor(
  name='SuggestGeoTargetConstantsResponse',
  full_name='google.ads.googleads.v1.services.SuggestGeoTargetConstantsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='geo_target_constant_suggestions', full_name='google.ads.googleads.v1.services.SuggestGeoTargetConstantsResponse.geo_target_constant_suggestions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=784,
  serialized_end=923,
)


_GEOTARGETCONSTANTSUGGESTION = _descriptor.Descriptor(
  name='GeoTargetConstantSuggestion',
  full_name='google.ads.googleads.v1.services.GeoTargetConstantSuggestion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='locale', full_name='google.ads.googleads.v1.services.GeoTargetConstantSuggestion.locale', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reach', full_name='google.ads.googleads.v1.services.GeoTargetConstantSuggestion.reach', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_term', full_name='google.ads.googleads.v1.services.GeoTargetConstantSuggestion.search_term', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_constant', full_name='google.ads.googleads.v1.services.GeoTargetConstantSuggestion.geo_target_constant', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_constant_parents', full_name='google.ads.googleads.v1.services.GeoTargetConstantSuggestion.geo_target_constant_parents', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=926,
  serialized_end=1270,
)

_SUGGESTGEOTARGETCONSTANTSREQUEST_LOCATIONNAMES.fields_by_name['names'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SUGGESTGEOTARGETCONSTANTSREQUEST_LOCATIONNAMES.containing_type = _SUGGESTGEOTARGETCONSTANTSREQUEST
_SUGGESTGEOTARGETCONSTANTSREQUEST_GEOTARGETS.fields_by_name['geo_target_constants'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SUGGESTGEOTARGETCONSTANTSREQUEST_GEOTARGETS.containing_type = _SUGGESTGEOTARGETCONSTANTSREQUEST
_SUGGESTGEOTARGETCONSTANTSREQUEST.fields_by_name['locale'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SUGGESTGEOTARGETCONSTANTSREQUEST.fields_by_name['country_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SUGGESTGEOTARGETCONSTANTSREQUEST.fields_by_name['location_names'].message_type = _SUGGESTGEOTARGETCONSTANTSREQUEST_LOCATIONNAMES
_SUGGESTGEOTARGETCONSTANTSREQUEST.fields_by_name['geo_targets'].message_type = _SUGGESTGEOTARGETCONSTANTSREQUEST_GEOTARGETS
_SUGGESTGEOTARGETCONSTANTSREQUEST.oneofs_by_name['query'].fields.append(
  _SUGGESTGEOTARGETCONSTANTSREQUEST.fields_by_name['location_names'])
_SUGGESTGEOTARGETCONSTANTSREQUEST.fields_by_name['location_names'].containing_oneof = _SUGGESTGEOTARGETCONSTANTSREQUEST.oneofs_by_name['query']
_SUGGESTGEOTARGETCONSTANTSREQUEST.oneofs_by_name['query'].fields.append(
  _SUGGESTGEOTARGETCONSTANTSREQUEST.fields_by_name['geo_targets'])
_SUGGESTGEOTARGETCONSTANTSREQUEST.fields_by_name['geo_targets'].containing_oneof = _SUGGESTGEOTARGETCONSTANTSREQUEST.oneofs_by_name['query']
_SUGGESTGEOTARGETCONSTANTSRESPONSE.fields_by_name['geo_target_constant_suggestions'].message_type = _GEOTARGETCONSTANTSUGGESTION
_GEOTARGETCONSTANTSUGGESTION.fields_by_name['locale'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GEOTARGETCONSTANTSUGGESTION.fields_by_name['reach'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_GEOTARGETCONSTANTSUGGESTION.fields_by_name['search_term'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GEOTARGETCONSTANTSUGGESTION.fields_by_name['geo_target_constant'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_geo__target__constant__pb2._GEOTARGETCONSTANT
_GEOTARGETCONSTANTSUGGESTION.fields_by_name['geo_target_constant_parents'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_geo__target__constant__pb2._GEOTARGETCONSTANT
DESCRIPTOR.message_types_by_name['GetGeoTargetConstantRequest'] = _GETGEOTARGETCONSTANTREQUEST
DESCRIPTOR.message_types_by_name['SuggestGeoTargetConstantsRequest'] = _SUGGESTGEOTARGETCONSTANTSREQUEST
DESCRIPTOR.message_types_by_name['SuggestGeoTargetConstantsResponse'] = _SUGGESTGEOTARGETCONSTANTSRESPONSE
DESCRIPTOR.message_types_by_name['GeoTargetConstantSuggestion'] = _GEOTARGETCONSTANTSUGGESTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetGeoTargetConstantRequest = _reflection.GeneratedProtocolMessageType('GetGeoTargetConstantRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETGEOTARGETCONSTANTREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.geo_target_constant_service_pb2'
  ,
  __doc__ = """Request message for
  [GeoTargetConstantService.GetGeoTargetConstant][google.ads.googleads.v1.services.GeoTargetConstantService.GetGeoTargetConstant].
  
  
  Attributes:
      resource_name:
          The resource name of the geo target constant to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GetGeoTargetConstantRequest)
  ))
_sym_db.RegisterMessage(GetGeoTargetConstantRequest)

SuggestGeoTargetConstantsRequest = _reflection.GeneratedProtocolMessageType('SuggestGeoTargetConstantsRequest', (_message.Message,), dict(

  LocationNames = _reflection.GeneratedProtocolMessageType('LocationNames', (_message.Message,), dict(
    DESCRIPTOR = _SUGGESTGEOTARGETCONSTANTSREQUEST_LOCATIONNAMES,
    __module__ = 'google.ads.googleads_v1.proto.services.geo_target_constant_service_pb2'
    ,
    __doc__ = """A list of location names.
    
    
    Attributes:
        names:
            A list of location names.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.SuggestGeoTargetConstantsRequest.LocationNames)
    ))
  ,

  GeoTargets = _reflection.GeneratedProtocolMessageType('GeoTargets', (_message.Message,), dict(
    DESCRIPTOR = _SUGGESTGEOTARGETCONSTANTSREQUEST_GEOTARGETS,
    __module__ = 'google.ads.googleads_v1.proto.services.geo_target_constant_service_pb2'
    ,
    __doc__ = """A list of geo target constant resource names.
    
    
    Attributes:
        geo_target_constants:
            A list of geo target constant resource names.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.SuggestGeoTargetConstantsRequest.GeoTargets)
    ))
  ,
  DESCRIPTOR = _SUGGESTGEOTARGETCONSTANTSREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.geo_target_constant_service_pb2'
  ,
  __doc__ = """Request message for
  [GeoTargetConstantService.SuggestGeoTargetConstantsRequest][].
  
  
  Attributes:
      locale:
          If possible, returned geo targets are translated using this
          locale. If not, en is used by default. This is also used as a
          hint for returned geo targets.
      country_code:
          Returned geo targets are restricted to this country code.
      query:
          Required. A selector of geo target constants.
      location_names:
          The location names to search by. At most 25 names can be set.
      geo_targets:
          The geo target constant resource names to filter by.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.SuggestGeoTargetConstantsRequest)
  ))
_sym_db.RegisterMessage(SuggestGeoTargetConstantsRequest)
_sym_db.RegisterMessage(SuggestGeoTargetConstantsRequest.LocationNames)
_sym_db.RegisterMessage(SuggestGeoTargetConstantsRequest.GeoTargets)

SuggestGeoTargetConstantsResponse = _reflection.GeneratedProtocolMessageType('SuggestGeoTargetConstantsResponse', (_message.Message,), dict(
  DESCRIPTOR = _SUGGESTGEOTARGETCONSTANTSRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.geo_target_constant_service_pb2'
  ,
  __doc__ = """Response message for
  [GeoTargetConstantService.SuggestGeoTargetConstants][google.ads.googleads.v1.services.GeoTargetConstantService.SuggestGeoTargetConstants]
  
  
  Attributes:
      geo_target_constant_suggestions:
          Geo target constant suggestions.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.SuggestGeoTargetConstantsResponse)
  ))
_sym_db.RegisterMessage(SuggestGeoTargetConstantsResponse)

GeoTargetConstantSuggestion = _reflection.GeneratedProtocolMessageType('GeoTargetConstantSuggestion', (_message.Message,), dict(
  DESCRIPTOR = _GEOTARGETCONSTANTSUGGESTION,
  __module__ = 'google.ads.googleads_v1.proto.services.geo_target_constant_service_pb2'
  ,
  __doc__ = """A geo target constant suggestion.
  
  
  Attributes:
      locale:
          The language this GeoTargetConstantSuggestion is currently
          translated to. It affects the name of geo target fields. For
          example, if locale=en, then name=Spain. If locale=es, then
          name=España. The default locale will be returned if no
          translation exists for the locale in the request.
      reach:
          Approximate user population that will be targeted, rounded to
          the nearest 100.
      search_term:
          If the request searched by location name, this is the location
          name that matched the geo target.
      geo_target_constant:
          The GeoTargetConstant result.
      geo_target_constant_parents:
          The list of parents of the geo target constant.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GeoTargetConstantSuggestion)
  ))
_sym_db.RegisterMessage(GeoTargetConstantSuggestion)


DESCRIPTOR._options = None

_GEOTARGETCONSTANTSERVICE = _descriptor.ServiceDescriptor(
  name='GeoTargetConstantService',
  full_name='google.ads.googleads.v1.services.GeoTargetConstantService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1273,
  serialized_end=1701,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetGeoTargetConstant',
    full_name='google.ads.googleads.v1.services.GeoTargetConstantService.GetGeoTargetConstant',
    index=0,
    containing_service=None,
    input_type=_GETGEOTARGETCONSTANTREQUEST,
    output_type=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_geo__target__constant__pb2._GEOTARGETCONSTANT,
    serialized_options=_b('\202\323\344\223\002*\022(/v1/{resource_name=geoTargetConstants/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='SuggestGeoTargetConstants',
    full_name='google.ads.googleads.v1.services.GeoTargetConstantService.SuggestGeoTargetConstants',
    index=1,
    containing_service=None,
    input_type=_SUGGESTGEOTARGETCONSTANTSREQUEST,
    output_type=_SUGGESTGEOTARGETCONSTANTSRESPONSE,
    serialized_options=_b('\202\323\344\223\002#\"\036/v1/geoTargetConstants:suggest:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_GEOTARGETCONSTANTSERVICE)

DESCRIPTOR.services_by_name['GeoTargetConstantService'] = _GEOTARGETCONSTANTSERVICE

# @@protoc_insertion_point(module_scope)



# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""A gRPC Interceptor that is responsible for logging requests and responses.

This class is initialized in the GoogleAdsClient and passed into a grpc
intercept_channel whenever a new service is initialized. It intercepts requests
and responses, parses them into a human readable structure and logs them using
the passed in logger instance.
"""

from grpc import UnaryUnaryClientInterceptor
import json
import logging

from .interceptor_mixin import InterceptorMixin


class LoggingInterceptor(InterceptorMixin, UnaryUnaryClientInterceptor):
    """An interceptor that logs rpc requests and responses."""

    _FULL_REQUEST_LOG_LINE = ('Request\n-------\nMethod: {}\nHost: {}\n'
                              'Headers: {}\nRequest: {}\n\nResponse\n-------\n'
                              'Headers: {}\nResponse: {}\n')
    _FULL_FAULT_LOG_LINE = ('Request\n-------\nMethod: {}\nHost: {}\n'
                            'Headers: {}\nRequest: {}\n\nResponse\n-------\n'
                            'Headers: {}\nFault: {}\n')
    _SUMMARY_LOG_LINE = ('Request made: ClientCustomerId: {}, Host: {}, '
                         'Method: {}, RequestId: {}, IsFault: {}, '
                         'FaultMessage: {}')

    def __init__(self, logger, endpoint=None):
        """Initializer for the LoggingInterceptor.

        Args:
            logger: An instance of logging.Logger.
            endpoint: a str specifying the endpoint for requests.
        """
        self.endpoint = endpoint
        self.logger = logger

    def _get_trailing_metadata(self, response):
        """Retrieves trailing metadata from a response object.

        If the exception is a GoogleAdsException the trailing metadata will be
        on its error object, otherwise it will be on the response object.

        Returns:
            A tuple of metadatum representing response header key value pairs.

        Args:
            response: A grpc.Call/grpc.Future instance.
        """
        try:
            trailing_metadata = response.trailing_metadata()

            if not trailing_metadata:
                return self.get_trailing_metadata_from_interceptor_exception(
                    response.exception())

            return trailing_metadata
        except AttributeError:
            return self.get_trailing_metadata_from_interceptor_exception(
                response.exception())

    def _get_initial_metadata(self, client_call_details):
        """Retrieves the initial metadata from client_call_details.

        Returns an empty tuple if metadata isn't present on the
        client_call_details object.

        Returns:
            A tuple of metadatum representing request header key value pairs.

        Args:
            client_call_details: An instance of grpc.ClientCallDetails.
        """
        return getattr(client_call_details, 'metadata', tuple())

    def _get_call_method(self, client_call_details):
        """Retrieves the call method from client_call_details.

        Returns None if the method is not present on the client_call_details
        object.

        Returns:
            A str with the call method or None if it isn't present.

        Args:
            client_call_details: An instance of grpc.ClientCallDetails.
        """
        return getattr(client_call_details, 'method', None)

    def _get_customer_id(self, request):
        """Retrieves the customer_id from the grpc request.

        Returns None if a customer_id is not present on the request object.

        Returns:
            A str with the customer id from the request or None if it isn't
            present.

        Args:
            request: An instance of a request proto message.
        """
        return getattr(request, 'customer_id', None)

    def _parse_exception_to_str(self, exception):
        """Parses response exception object to str for logging.

        Returns:
            A str representing a exception from the API.

        Args:
            exception: A grpc.Call instance.
        """
        try:
            # If the exception is from the Google Ads API then the failure
            # attribute will be an instance of GoogleAdsFailure and can be
            # concatenated into a log string.
            return exception.failure
        except AttributeError:
            try:
                # if exception.failure isn't present then it's likely this is a
                # transport error with a .debug_error_string method and the
                # returned JSON string will need to be formatted.
                return self.format_json_object(json.loads(
                    exception.debug_error_string()))
            except (AttributeError, ValueError):
                # if both attempts to retrieve serializable error data fail
                # then simply return an empty JSON string
                return '{}'

    def _get_fault_message(self, exception):
        """Retrieves a fault/error message from an exception object.

        Returns None if no error message can be found on the exception.

        Returns:
            A str with an error message or None if one cannot be found.

        Args:
            response: A grpc.Call/grpc.Future instance.
            exception: A grpc.Call instance.
        """
        try:
            return exception.failure.errors[0].message
        except AttributeError:
            try:
                return exception.details()
            except AttributeError:
                return None

    def _log_successful_request(self, method, customer_id, metadata_json,
                                request_id, request, trailing_metadata_json,
                                response):
        """Handles logging of a successful request.

        Args:
            method: The method of the request.
            customer_id: The customer ID associated with the request.
            metadata_json: A JSON str of initial_metadata.
            request_id: A unique ID for the request provided in the response.
            request: An instance of a request proto message.
            trailing_metadata_json: A JSON str of trailing_metadata.
            response: A grpc.Call/grpc.Future instance.
        """
        self.logger.debug(self._FULL_REQUEST_LOG_LINE.format(method, self.endpoint,
                      metadata_json, request, trailing_metadata_json,
                      response.result()))

        self.logger.info(self._SUMMARY_LOG_LINE.format(customer_id, self.endpoint,
                     method, request_id, False, None))

    def _log_failed_request(self, method, customer_id, metadata_json,
                            request_id, request, trailing_metadata_json,
                            response):
        """Handles logging of a failed request.

        Args:
            method: The method of the request.
            customer_id: The customer ID associated with the request.
            metadata_json: A JSON str of initial_metadata.
            request_id: A unique ID for the request provided in the response.
            request: An instance of a request proto message.
            trailing_metadata_json: A JSON str of trailing_metadata.
            response: A JSON str of the the response message.
        """
        exception_str = self._parse_exception_to_str(response.exception())
        fault_message = self._get_fault_message(response.exception())

        self.logger.info(self._FULL_FAULT_LOG_LINE.format(method, self.endpoint,
                     metadata_json, request, trailing_metadata_json,
                     exception_str))

        self.logger.warning(self._SUMMARY_LOG_LINE.format(customer_id, self.endpoint,
                        method, request_id, True, fault_message))

    def _log_request(self, client_call_details, request, response):
        """Handles logging all requests.

        Args:
            client_call_details: An instance of grpc.ClientCallDetails.
            request: An instance of a request proto message.
            response: A grpc.Call/grpc.Future instance.
        """
        method = self._get_call_method(client_call_details)
        customer_id = self._get_customer_id(request)
        initial_metadata = self._get_initial_metadata(client_call_details)
        initial_metadata_json = self.parse_metadata_to_json(initial_metadata)
        trailing_metadata = self._get_trailing_metadata(response)
        request_id = self.get_request_id_from_metadata(trailing_metadata)
        trailing_metadata_json = self.parse_metadata_to_json(trailing_metadata)

        if response.exception():
            self._log_failed_request(method, customer_id, initial_metadata_json,
                                     request_id, request,
                                     trailing_metadata_json, response)
        else:
            self._log_successful_request(method, customer_id,
                                         initial_metadata_json, request_id,
                                         request, trailing_metadata_json,
                                         response)

    def intercept_unary_unary(self, continuation, client_call_details, request):
        """Intercepts and logs API interactions.

        Overrides abstract method defined in grpc.UnaryUnaryClientInterceptor.

        Returns:
            A grpc.Call/grpc.Future instance representing a service response.
        """
        response = continuation(client_call_details, request)

        if self.logger.isEnabledFor(logging.WARNING):
            self._log_request(client_call_details, request, response)

        return response


# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Accesses the google.ads.googleads.v1.services GoogleAdsService API."""

import functools
import pkg_resources
import warnings

from google.oauth2 import service_account
import google.api_core.gapic_v1.client_info
import google.api_core.gapic_v1.config
import google.api_core.gapic_v1.method
import google.api_core.grpc_helpers
import google.api_core.page_iterator

from google.ads.google_ads.v1.services import google_ads_service_client_config
from google.ads.google_ads.v1.services.transports import google_ads_service_grpc_transport
from google.ads.google_ads.v1.proto.services import google_ads_service_pb2

_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution(
    'google-ads', ).version


class GoogleAdsServiceClient(object):
    """Service to fetch data and metrics across resources."""

    SERVICE_ADDRESS = 'googleads.googleapis.com:443'
    """The default address of the service."""

    # The name of the interface for this client. This is the key used to
    # find the method configuration in the client_config dictionary.
    _INTERFACE_NAME = 'google.ads.googleads.v1.services.GoogleAdsService'

    @classmethod
    def from_service_account_file(cls, filename, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
        file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            GoogleAdsServiceClient: The constructed client.
        """
        credentials = service_account.Credentials.from_service_account_file(
            filename)
        kwargs['credentials'] = credentials
        return cls(*args, **kwargs)

    from_service_account_json = from_service_account_file

    def __init__(self,
                 transport=None,
                 channel=None,
                 credentials=None,
                 client_config=None,
                 client_info=None):
        """Constructor.

        Args:
            transport (Union[~.GoogleAdsServiceGrpcTransport,
                    Callable[[~.Credentials, type], ~.GoogleAdsServiceGrpcTransport]): A transport
                instance, responsible for actually making the API calls.
                The default transport uses the gRPC protocol.
                This argument may also be a callable which returns a
                transport instance. Callables will be sent the credentials
                as the first argument and the default transport class as
                the second argument.
            channel (grpc.Channel): DEPRECATED. A ``Channel`` instance
                through which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
                This argument is mutually exclusive with providing a
                transport instance to ``transport``; doing so will raise
                an exception.
            client_config (dict): DEPRECATED. A dictionary of call options for
                each method. If not specified, the default configuration is used.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
        """
        # Raise deprecation warnings for things we want to go away.
        if client_config is not None:
            warnings.warn(
                'The `client_config` argument is deprecated.',
                PendingDeprecationWarning,
                stacklevel=2)
        else:
            client_config = google_ads_service_client_config.config

        if channel:
            warnings.warn(
                'The `channel` argument is deprecated; use '
                '`transport` instead.',
                PendingDeprecationWarning,
                stacklevel=2)

        # Instantiate the transport.
        # The transport is responsible for handling serialization and
        # deserialization and actually sending data to the service.
        if transport:
            if callable(transport):
                self.transport = transport(
                    credentials=credentials,
                    default_class=google_ads_service_grpc_transport.
                    GoogleAdsServiceGrpcTransport,
                )
            else:
                if credentials:
                    raise ValueError(
                        'Received both a transport instance and '
                        'credentials; these are mutually exclusive.')
                self.transport = transport
        else:
            self.transport = google_ads_service_grpc_transport.GoogleAdsServiceGrpcTransport(
                address=self.SERVICE_ADDRESS,
                channel=channel,
                credentials=credentials,
            )

        if client_info is None:
            client_info = google.api_core.gapic_v1.client_info.ClientInfo(
                gapic_version=_GAPIC_LIBRARY_VERSION, )
        else:
            client_info.gapic_version = _GAPIC_LIBRARY_VERSION
        self._client_info = client_info

        # Parse out the default settings for retry and timeout for each RPC
        # from the client configuration.
        # (Ordinarily, these are the defaults specified in the `*_config.py`
        # file next to this one.)
        self._method_configs = google.api_core.gapic_v1.config.parse_method_configs(
            client_config['interfaces'][self._INTERFACE_NAME], )

        # Save a dictionary of cached API call functions.
        # These are the actual callables which invoke the proper
        # transport methods, wrapped with `wrap_method` to add retry,
        # timeout, and the like.
        self._inner_api_calls = {}

    # Service calls
    def search(self,
               customer_id,
               query,
               page_size=None,
               validate_only=None,
               retry=google.api_core.gapic_v1.method.DEFAULT,
               timeout=google.api_core.gapic_v1.method.DEFAULT,
               metadata=None):
        """
        Returns all rows that match the search query.

        Args:
            customer_id (str): The ID of the customer being queried.
            query (str): The query string.
            page_size (int): The maximum number of resources contained in the
                underlying API response. If page streaming is performed per-
                resource, this parameter does not affect the return value. If page
                streaming is performed per-page, this determines the maximum number
                of resources in a page.
            validate_only (bool): If true, the request is validated but not executed.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.gax.PageIterator` instance. By default, this
            is an iterable of :class:`~google.ads.googleads_v1.types.GoogleAdsRow` instances.
            This object can also be configured to iterate over the pages
            of the response through the `options` parameter.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'search' not in self._inner_api_calls:
            self._inner_api_calls[
                'search'] = google.api_core.gapic_v1.method.wrap_method(
                    self.transport.search,
                    default_retry=self._method_configs['Search'].retry,
                    default_timeout=self._method_configs['Search'].timeout,
                    client_info=self._client_info,
                )

        request = google_ads_service_pb2.SearchGoogleAdsRequest(
            customer_id=customer_id,
            query=query,
            page_size=page_size,
            validate_only=validate_only,
        )
        iterator = google.api_core.page_iterator.GRPCIterator(
            client=None,
            method=functools.partial(
                self._inner_api_calls['search'],
                retry=retry,
                timeout=timeout,
                metadata=metadata),
            request=request,
            items_field='results',
            request_token_field='page_token',
            response_token_field='next_page_token',
        )
        return iterator

    def mutate(self,
               customer_id,
               mutate_operations,
               partial_failure=None,
               validate_only=None,
               retry=google.api_core.gapic_v1.method.DEFAULT,
               timeout=google.api_core.gapic_v1.method.DEFAULT,
               metadata=None):
        """
        Creates, updates, or removes resources. This method supports atomic
        transactions with multiple types of resources. For example, you can
        atomically create a campaign and a campaign budget, or perform up to
        thousands of mutates atomically.

        This method is essentially a wrapper around a series of mutate methods.
        The only features it offers over calling those methods directly are: -
        Atomic transactions - Temp resource names (described below) - Somewhat
        reduced latency over making a series of mutate calls.

        Note: Only resources that support atomic transactions are included, so
        this method can't replace all calls to individual services.

        ## Atomic Transaction Benefits

        Atomicity makes error handling much easier. If you're making a series of
        changes and one fails, it can leave your account in an inconsistent
        state. With atomicity, you either reach the desired state directly, or
        the request fails and you can retry.

        ## Temp Resource Names

        Temp resource names are a special type of resource name used to create a
        resource and reference that resource in the same request. For example,
        if a campaign budget is created with 'resource\_name' equal to
        'customers/123/campaignBudgets/-1', that resource name can be reused in
        the 'Campaign.budget' field in the same request. That way, the two
        resources are created and linked atomically.

        To create a temp resource name, put a negative number in the part of the
        name that the server would normally allocate.

        Note: - Resources must be created with a temp name before the name can
        be reused. For example, the previous CampaignBudget+Campaign example
        would fail if the mutate order was reversed. - Temp names are not
        remembered across requests. - There's no limit to the number of temp
        names in a request. - Each temp name must use a unique negative number,
        even if the resource types differ.

        ## Latency

        It's important to group mutates by resource type or the request may time
        out and fail. Latency is roughly equal to a series of calls to
        individual mutate methods, where each change in resource type is a new
        call. For example, mutating 10 campaigns then 10 ad groups is like 2
        calls, while mutating 1 campaign, 1 ad group, 1 campaign, 1 ad group is
        like 4 calls.

        Args:
            customer_id (str): The ID of the customer whose resources are being modified.
            mutate_operations (list[Union[dict, ~google.ads.googleads_v1.types.MutateOperation]]): The list of operations to perform on individual resources.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.ads.googleads_v1.types.MutateOperation`
            partial_failure (bool): If true, successful operations will be carried out and invalid
                operations will return errors. If false, all operations will be carried
                out in one transaction if and only if they are all valid.
                Default is false.
            validate_only (bool): If true, the request is validated but not executed. Only errors are
                returned, not results.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.ads.googleads_v1.types.MutateGoogleAdsResponse` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'mutate' not in self._inner_api_calls:
            self._inner_api_calls[
                'mutate'] = google.api_core.gapic_v1.method.wrap_method(
                    self.transport.mutate,
                    default_retry=self._method_configs['Mutate'].retry,
                    default_timeout=self._method_configs['Mutate'].timeout,
                    client_info=self._client_info,
                )

        request = google_ads_service_pb2.MutateGoogleAdsRequest(
            customer_id=customer_id,
            mutate_operations=mutate_operations,
            partial_failure=partial_failure,
            validate_only=validate_only,
        )
        return self._inner_api_calls['mutate'](
            request, retry=retry, timeout=timeout, metadata=metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/services/feed_mapping_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.resources import feed_mapping_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__mapping__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/services/feed_mapping_service.proto',
  package='google.ads.googleads.v2.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v2.servicesB\027FeedMappingServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V2.Services\312\002 Google\\Ads\\GoogleAds\\V2\\Services\352\002$Google::Ads::GoogleAds::V2::Services'),
  serialized_pb=_b('\nAgoogle/ads/googleads_v2/proto/services/feed_mapping_service.proto\x12 google.ads.googleads.v2.services\x1a:google/ads/googleads_v2/proto/resources/feed_mapping.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/rpc/status.proto\x1a\x17google/api/client.proto\".\n\x15GetFeedMappingRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\xac\x01\n\x19MutateFeedMappingsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12J\n\noperations\x18\x02 \x03(\x0b\x32\x36.google.ads.googleads.v2.services.FeedMappingOperation\x12\x17\n\x0fpartial_failure\x18\x03 \x01(\x08\x12\x15\n\rvalidate_only\x18\x04 \x01(\x08\"w\n\x14\x46\x65\x65\x64MappingOperation\x12@\n\x06\x63reate\x18\x01 \x01(\x0b\x32..google.ads.googleads.v2.resources.FeedMappingH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"\x9b\x01\n\x1aMutateFeedMappingsResponse\x12\x31\n\x15partial_failure_error\x18\x03 \x01(\x0b\x32\x12.google.rpc.Status\x12J\n\x07results\x18\x02 \x03(\x0b\x32\x39.google.ads.googleads.v2.services.MutateFeedMappingResult\"0\n\x17MutateFeedMappingResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xb5\x03\n\x12\x46\x65\x65\x64MappingService\x12\xb1\x01\n\x0eGetFeedMapping\x12\x37.google.ads.googleads.v2.services.GetFeedMappingRequest\x1a..google.ads.googleads.v2.resources.FeedMapping\"6\x82\xd3\xe4\x93\x02\x30\x12./v2/{resource_name=customers/*/feedMappings/*}\x12\xcd\x01\n\x12MutateFeedMappings\x12;.google.ads.googleads.v2.services.MutateFeedMappingsRequest\x1a<.google.ads.googleads.v2.services.MutateFeedMappingsResponse\"<\x82\xd3\xe4\x93\x02\x36\"1/v2/customers/{customer_id=*}/feedMappings:mutate:\x01*\x1a\x1b\xca\x41\x18googleads.googleapis.comB\xfe\x01\n$com.google.ads.googleads.v2.servicesB\x17\x46\x65\x65\x64MappingServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V2.Services\xca\x02 Google\\Ads\\GoogleAds\\V2\\Services\xea\x02$Google::Ads::GoogleAds::V2::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__mapping__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_client__pb2.DESCRIPTOR,])




_GETFEEDMAPPINGREQUEST = _descriptor.Descriptor(
  name='GetFeedMappingRequest',
  full_name='google.ads.googleads.v2.services.GetFeedMappingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.GetFeedMappingRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=289,
)


_MUTATEFEEDMAPPINGSREQUEST = _descriptor.Descriptor(
  name='MutateFeedMappingsRequest',
  full_name='google.ads.googleads.v2.services.MutateFeedMappingsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.MutateFeedMappingsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v2.services.MutateFeedMappingsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure', full_name='google.ads.googleads.v2.services.MutateFeedMappingsRequest.partial_failure', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v2.services.MutateFeedMappingsRequest.validate_only', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=464,
)


_FEEDMAPPINGOPERATION = _descriptor.Descriptor(
  name='FeedMappingOperation',
  full_name='google.ads.googleads.v2.services.FeedMappingOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v2.services.FeedMappingOperation.create', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v2.services.FeedMappingOperation.remove', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v2.services.FeedMappingOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=466,
  serialized_end=585,
)


_MUTATEFEEDMAPPINGSRESPONSE = _descriptor.Descriptor(
  name='MutateFeedMappingsResponse',
  full_name='google.ads.googleads.v2.services.MutateFeedMappingsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v2.services.MutateFeedMappingsResponse.partial_failure_error', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v2.services.MutateFeedMappingsResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=743,
)


_MUTATEFEEDMAPPINGRESULT = _descriptor.Descriptor(
  name='MutateFeedMappingResult',
  full_name='google.ads.googleads.v2.services.MutateFeedMappingResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.MutateFeedMappingResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=745,
  serialized_end=793,
)

_MUTATEFEEDMAPPINGSREQUEST.fields_by_name['operations'].message_type = _FEEDMAPPINGOPERATION
_FEEDMAPPINGOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__mapping__pb2._FEEDMAPPING
_FEEDMAPPINGOPERATION.oneofs_by_name['operation'].fields.append(
  _FEEDMAPPINGOPERATION.fields_by_name['create'])
_FEEDMAPPINGOPERATION.fields_by_name['create'].containing_oneof = _FEEDMAPPINGOPERATION.oneofs_by_name['operation']
_FEEDMAPPINGOPERATION.oneofs_by_name['operation'].fields.append(
  _FEEDMAPPINGOPERATION.fields_by_name['remove'])
_FEEDMAPPINGOPERATION.fields_by_name['remove'].containing_oneof = _FEEDMAPPINGOPERATION.oneofs_by_name['operation']
_MUTATEFEEDMAPPINGSRESPONSE.fields_by_name['partial_failure_error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_MUTATEFEEDMAPPINGSRESPONSE.fields_by_name['results'].message_type = _MUTATEFEEDMAPPINGRESULT
DESCRIPTOR.message_types_by_name['GetFeedMappingRequest'] = _GETFEEDMAPPINGREQUEST
DESCRIPTOR.message_types_by_name['MutateFeedMappingsRequest'] = _MUTATEFEEDMAPPINGSREQUEST
DESCRIPTOR.message_types_by_name['FeedMappingOperation'] = _FEEDMAPPINGOPERATION
DESCRIPTOR.message_types_by_name['MutateFeedMappingsResponse'] = _MUTATEFEEDMAPPINGSRESPONSE
DESCRIPTOR.message_types_by_name['MutateFeedMappingResult'] = _MUTATEFEEDMAPPINGRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetFeedMappingRequest = _reflection.GeneratedProtocolMessageType('GetFeedMappingRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETFEEDMAPPINGREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.feed_mapping_service_pb2'
  ,
  __doc__ = """Request message for
  [FeedMappingService.GetFeedMapping][google.ads.googleads.v2.services.FeedMappingService.GetFeedMapping].
  
  
  Attributes:
      resource_name:
          The resource name of the feed mapping to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GetFeedMappingRequest)
  ))
_sym_db.RegisterMessage(GetFeedMappingRequest)

MutateFeedMappingsRequest = _reflection.GeneratedProtocolMessageType('MutateFeedMappingsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDMAPPINGSREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.feed_mapping_service_pb2'
  ,
  __doc__ = """Request message for
  [FeedMappingService.MutateFeedMappings][google.ads.googleads.v2.services.FeedMappingService.MutateFeedMappings].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose feed mappings are being modified.
      operations:
          The list of operations to perform on individual feed mappings.
      partial_failure:
          If true, successful operations will be carried out and invalid
          operations will return errors. If false, all operations will
          be carried out in one transaction if and only if they are all
          valid. Default is false.
      validate_only:
          If true, the request is validated but not executed. Only
          errors are returned, not results.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateFeedMappingsRequest)
  ))
_sym_db.RegisterMessage(MutateFeedMappingsRequest)

FeedMappingOperation = _reflection.GeneratedProtocolMessageType('FeedMappingOperation', (_message.Message,), dict(
  DESCRIPTOR = _FEEDMAPPINGOPERATION,
  __module__ = 'google.ads.googleads_v2.proto.services.feed_mapping_service_pb2'
  ,
  __doc__ = """A single operation (create, remove) on a feed mapping.
  
  
  Attributes:
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          feed mapping.
      remove:
          Remove operation: A resource name for the removed feed mapping
          is expected, in this format:  ``customers/{customer_id}/feedMa
          ppings/{feed_id}~{feed_mapping_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.FeedMappingOperation)
  ))
_sym_db.RegisterMessage(FeedMappingOperation)

MutateFeedMappingsResponse = _reflection.GeneratedProtocolMessageType('MutateFeedMappingsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDMAPPINGSRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.feed_mapping_service_pb2'
  ,
  __doc__ = """Response message for a feed mapping mutate.
  
  
  Attributes:
      partial_failure_error:
          Errors that pertain to operation failures in the partial
          failure mode. Returned only when partial\_failure = true and
          all errors occur inside the operations. If any errors occur
          outside the operations (e.g. auth errors), we return an RPC
          level error.
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateFeedMappingsResponse)
  ))
_sym_db.RegisterMessage(MutateFeedMappingsResponse)

MutateFeedMappingResult = _reflection.GeneratedProtocolMessageType('MutateFeedMappingResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDMAPPINGRESULT,
  __module__ = 'google.ads.googleads_v2.proto.services.feed_mapping_service_pb2'
  ,
  __doc__ = """The result for the feed mapping mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateFeedMappingResult)
  ))
_sym_db.RegisterMessage(MutateFeedMappingResult)


DESCRIPTOR._options = None

_FEEDMAPPINGSERVICE = _descriptor.ServiceDescriptor(
  name='FeedMappingService',
  full_name='google.ads.googleads.v2.services.FeedMappingService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\312A\030googleads.googleapis.com'),
  serialized_start=796,
  serialized_end=1233,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetFeedMapping',
    full_name='google.ads.googleads.v2.services.FeedMappingService.GetFeedMapping',
    index=0,
    containing_service=None,
    input_type=_GETFEEDMAPPINGREQUEST,
    output_type=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__mapping__pb2._FEEDMAPPING,
    serialized_options=_b('\202\323\344\223\0020\022./v2/{resource_name=customers/*/feedMappings/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateFeedMappings',
    full_name='google.ads.googleads.v2.services.FeedMappingService.MutateFeedMappings',
    index=1,
    containing_service=None,
    input_type=_MUTATEFEEDMAPPINGSREQUEST,
    output_type=_MUTATEFEEDMAPPINGSRESPONSE,
    serialized_options=_b('\202\323\344\223\0026\"1/v2/customers/{customer_id=*}/feedMappings:mutate:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_FEEDMAPPINGSERVICE)

DESCRIPTOR.services_by_name['FeedMappingService'] = _FEEDMAPPINGSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/services/recommendation_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import extensions_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_extensions__pb2
from google.ads.google_ads.v1.proto.enums import keyword_match_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2
from google.ads.google_ads.v1.proto.resources import ad_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__pb2
from google.ads.google_ads.v1.proto.resources import recommendation_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_recommendation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/services/recommendation_service.proto',
  package='google.ads.googleads.v1.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v1.servicesB\032RecommendationServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V1.Services\312\002 Google\\Ads\\GoogleAds\\V1\\Services\352\002$Google::Ads::GoogleAds::V1::Services'),
  serialized_pb=_b('\nCgoogle/ads/googleads_v1/proto/services/recommendation_service.proto\x12 google.ads.googleads.v1.services\x1a\x35google/ads/googleads_v1/proto/common/extensions.proto\x1a<google/ads/googleads_v1/proto/enums/keyword_match_type.proto\x1a\x30google/ads/googleads_v1/proto/resources/ad.proto\x1a<google/ads/googleads_v1/proto/resources/recommendation.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17google/rpc/status.proto\"1\n\x18GetRecommendationRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x9e\x01\n\x1a\x41pplyRecommendationRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12R\n\noperations\x18\x02 \x03(\x0b\x32>.google.ads.googleads.v1.services.ApplyRecommendationOperation\x12\x17\n\x0fpartial_failure\x18\x03 \x01(\x08\"\x82\x0f\n\x1c\x41pplyRecommendationOperation\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12r\n\x0f\x63\x61mpaign_budget\x18\x02 \x01(\x0b\x32W.google.ads.googleads.v1.services.ApplyRecommendationOperation.CampaignBudgetParametersH\x00\x12\x62\n\x07text_ad\x18\x03 \x01(\x0b\x32O.google.ads.googleads.v1.services.ApplyRecommendationOperation.TextAdParametersH\x00\x12\x63\n\x07keyword\x18\x04 \x01(\x0b\x32P.google.ads.googleads.v1.services.ApplyRecommendationOperation.KeywordParametersH\x00\x12t\n\x11target_cpa_opt_in\x18\x05 \x01(\x0b\x32W.google.ads.googleads.v1.services.ApplyRecommendationOperation.TargetCpaOptInParametersH\x00\x12v\n\x11\x63\x61llout_extension\x18\x06 \x01(\x0b\x32Y.google.ads.googleads.v1.services.ApplyRecommendationOperation.CalloutExtensionParametersH\x00\x12p\n\x0e\x63\x61ll_extension\x18\x07 \x01(\x0b\x32V.google.ads.googleads.v1.services.ApplyRecommendationOperation.CallExtensionParametersH\x00\x12x\n\x12sitelink_extension\x18\x08 \x01(\x0b\x32Z.google.ads.googleads.v1.services.ApplyRecommendationOperation.SitelinkExtensionParametersH\x00\x12w\n\x12move_unused_budget\x18\t \x01(\x0b\x32Y.google.ads.googleads.v1.services.ApplyRecommendationOperation.MoveUnusedBudgetParametersH\x00\x1aY\n\x18\x43\x61mpaignBudgetParameters\x12=\n\x18new_budget_amount_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1a\x45\n\x10TextAdParameters\x12\x31\n\x02\x61\x64\x18\x01 \x01(\x0b\x32%.google.ads.googleads.v1.resources.Ad\x1a\xd2\x01\n\x11KeywordParameters\x12.\n\x08\x61\x64_group\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12X\n\nmatch_type\x18\x02 \x01(\x0e\x32\x44.google.ads.googleads.v1.enums.KeywordMatchTypeEnum.KeywordMatchType\x12\x33\n\x0e\x63pc_bid_micros\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1a\x9a\x01\n\x18TargetCpaOptInParameters\x12\x36\n\x11target_cpa_micros\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x46\n!new_campaign_budget_amount_micros\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1ai\n\x1a\x43\x61lloutExtensionParameters\x12K\n\x12\x63\x61llout_extensions\x18\x01 \x03(\x0b\x32/.google.ads.googleads.v1.common.CalloutFeedItem\x1a`\n\x17\x43\x61llExtensionParameters\x12\x45\n\x0f\x63\x61ll_extensions\x18\x01 \x03(\x0b\x32,.google.ads.googleads.v1.common.CallFeedItem\x1al\n\x1bSitelinkExtensionParameters\x12M\n\x13sitelink_extensions\x18\x01 \x03(\x0b\x32\x30.google.ads.googleads.v1.common.SitelinkFeedItem\x1aX\n\x1aMoveUnusedBudgetParameters\x12:\n\x15\x62udget_micros_to_move\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x12\n\x10\x61pply_parameters\"\x9e\x01\n\x1b\x41pplyRecommendationResponse\x12L\n\x07results\x18\x01 \x03(\x0b\x32;.google.ads.googleads.v1.services.ApplyRecommendationResult\x12\x31\n\x15partial_failure_error\x18\x02 \x01(\x0b\x32\x12.google.rpc.Status\"2\n\x19\x41pplyRecommendationResult\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\xf8\x01\n\x1c\x44ismissRecommendationRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12q\n\noperations\x18\x03 \x03(\x0b\x32].google.ads.googleads.v1.services.DismissRecommendationRequest.DismissRecommendationOperation\x12\x17\n\x0fpartial_failure\x18\x02 \x01(\x08\x1a\x37\n\x1e\x44ismissRecommendationOperation\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\xf6\x01\n\x1d\x44ismissRecommendationResponse\x12l\n\x07results\x18\x01 \x03(\x0b\x32[.google.ads.googleads.v1.services.DismissRecommendationResponse.DismissRecommendationResult\x12\x31\n\x15partial_failure_error\x18\x02 \x01(\x0b\x32\x12.google.rpc.Status\x1a\x34\n\x1b\x44ismissRecommendationResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\x89\x05\n\x15RecommendationService\x12\xbd\x01\n\x11GetRecommendation\x12:.google.ads.googleads.v1.services.GetRecommendationRequest\x1a\x31.google.ads.googleads.v1.resources.Recommendation\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v1/{resource_name=customers/*/recommendations/*}\x12\xd2\x01\n\x13\x41pplyRecommendation\x12<.google.ads.googleads.v1.services.ApplyRecommendationRequest\x1a=.google.ads.googleads.v1.services.ApplyRecommendationResponse\">\x82\xd3\xe4\x93\x02\x38\"3/v1/customers/{customer_id=*}/recommendations:apply:\x01*\x12\xda\x01\n\x15\x44ismissRecommendation\x12>.google.ads.googleads.v1.services.DismissRecommendationRequest\x1a?.google.ads.googleads.v1.services.DismissRecommendationResponse\"@\x82\xd3\xe4\x93\x02:\"5/v1/customers/{customer_id=*}/recommendations:dismiss:\x01*B\x81\x02\n$com.google.ads.googleads.v1.servicesB\x1aRecommendationServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V1.Services\xca\x02 Google\\Ads\\GoogleAds\\V1\\Services\xea\x02$Google::Ads::GoogleAds::V1::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_extensions__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_recommendation__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])




_GETRECOMMENDATIONREQUEST = _descriptor.Descriptor(
  name='GetRecommendationRequest',
  full_name='google.ads.googleads.v1.services.GetRecommendationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.GetRecommendationRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=421,
  serialized_end=470,
)


_APPLYRECOMMENDATIONREQUEST = _descriptor.Descriptor(
  name='ApplyRecommendationRequest',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v1.services.ApplyRecommendationRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v1.services.ApplyRecommendationRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure', full_name='google.ads.googleads.v1.services.ApplyRecommendationRequest.partial_failure', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=473,
  serialized_end=631,
)


_APPLYRECOMMENDATIONOPERATION_CAMPAIGNBUDGETPARAMETERS = _descriptor.Descriptor(
  name='CampaignBudgetParameters',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.CampaignBudgetParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_budget_amount_micros', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.CampaignBudgetParameters.new_budget_amount_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1601,
  serialized_end=1690,
)

_APPLYRECOMMENDATIONOPERATION_TEXTADPARAMETERS = _descriptor.Descriptor(
  name='TextAdParameters',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.TextAdParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ad', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.TextAdParameters.ad', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1692,
  serialized_end=1761,
)

_APPLYRECOMMENDATIONOPERATION_KEYWORDPARAMETERS = _descriptor.Descriptor(
  name='KeywordParameters',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.KeywordParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ad_group', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.KeywordParameters.ad_group', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_type', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.KeywordParameters.match_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpc_bid_micros', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.KeywordParameters.cpc_bid_micros', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1764,
  serialized_end=1974,
)

_APPLYRECOMMENDATIONOPERATION_TARGETCPAOPTINPARAMETERS = _descriptor.Descriptor(
  name='TargetCpaOptInParameters',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.TargetCpaOptInParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_cpa_micros', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.TargetCpaOptInParameters.target_cpa_micros', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_campaign_budget_amount_micros', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.TargetCpaOptInParameters.new_campaign_budget_amount_micros', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1977,
  serialized_end=2131,
)

_APPLYRECOMMENDATIONOPERATION_CALLOUTEXTENSIONPARAMETERS = _descriptor.Descriptor(
  name='CalloutExtensionParameters',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.CalloutExtensionParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='callout_extensions', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.CalloutExtensionParameters.callout_extensions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2133,
  serialized_end=2238,
)

_APPLYRECOMMENDATIONOPERATION_CALLEXTENSIONPARAMETERS = _descriptor.Descriptor(
  name='CallExtensionParameters',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.CallExtensionParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_extensions', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.CallExtensionParameters.call_extensions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2240,
  serialized_end=2336,
)

_APPLYRECOMMENDATIONOPERATION_SITELINKEXTENSIONPARAMETERS = _descriptor.Descriptor(
  name='SitelinkExtensionParameters',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.SitelinkExtensionParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sitelink_extensions', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.SitelinkExtensionParameters.sitelink_extensions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2338,
  serialized_end=2446,
)

_APPLYRECOMMENDATIONOPERATION_MOVEUNUSEDBUDGETPARAMETERS = _descriptor.Descriptor(
  name='MoveUnusedBudgetParameters',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.MoveUnusedBudgetParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='budget_micros_to_move', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.MoveUnusedBudgetParameters.budget_micros_to_move', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2448,
  serialized_end=2536,
)

_APPLYRECOMMENDATIONOPERATION = _descriptor.Descriptor(
  name='ApplyRecommendationOperation',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_budget', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.campaign_budget', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_ad', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.text_ad', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.keyword', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target_cpa_opt_in', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.target_cpa_opt_in', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='callout_extension', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.callout_extension', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_extension', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.call_extension', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sitelink_extension', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.sitelink_extension', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='move_unused_budget', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.move_unused_budget', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_APPLYRECOMMENDATIONOPERATION_CAMPAIGNBUDGETPARAMETERS, _APPLYRECOMMENDATIONOPERATION_TEXTADPARAMETERS, _APPLYRECOMMENDATIONOPERATION_KEYWORDPARAMETERS, _APPLYRECOMMENDATIONOPERATION_TARGETCPAOPTINPARAMETERS, _APPLYRECOMMENDATIONOPERATION_CALLOUTEXTENSIONPARAMETERS, _APPLYRECOMMENDATIONOPERATION_CALLEXTENSIONPARAMETERS, _APPLYRECOMMENDATIONOPERATION_SITELINKEXTENSIONPARAMETERS, _APPLYRECOMMENDATIONOPERATION_MOVEUNUSEDBUDGETPARAMETERS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='apply_parameters', full_name='google.ads.googleads.v1.services.ApplyRecommendationOperation.apply_parameters',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=634,
  serialized_end=2556,
)


_APPLYRECOMMENDATIONRESPONSE = _descriptor.Descriptor(
  name='ApplyRecommendationResponse',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v1.services.ApplyRecommendationResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v1.services.ApplyRecommendationResponse.partial_failure_error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2559,
  serialized_end=2717,
)


_APPLYRECOMMENDATIONRESULT = _descriptor.Descriptor(
  name='ApplyRecommendationResult',
  full_name='google.ads.googleads.v1.services.ApplyRecommendationResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.ApplyRecommendationResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2719,
  serialized_end=2769,
)


_DISMISSRECOMMENDATIONREQUEST_DISMISSRECOMMENDATIONOPERATION = _descriptor.Descriptor(
  name='DismissRecommendationOperation',
  full_name='google.ads.googleads.v1.services.DismissRecommendationRequest.DismissRecommendationOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.DismissRecommendationRequest.DismissRecommendationOperation.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2965,
  serialized_end=3020,
)

_DISMISSRECOMMENDATIONREQUEST = _descriptor.Descriptor(
  name='DismissRecommendationRequest',
  full_name='google.ads.googleads.v1.services.DismissRecommendationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v1.services.DismissRecommendationRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v1.services.DismissRecommendationRequest.operations', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure', full_name='google.ads.googleads.v1.services.DismissRecommendationRequest.partial_failure', index=2,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DISMISSRECOMMENDATIONREQUEST_DISMISSRECOMMENDATIONOPERATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2772,
  serialized_end=3020,
)


_DISMISSRECOMMENDATIONRESPONSE_DISMISSRECOMMENDATIONRESULT = _descriptor.Descriptor(
  name='DismissRecommendationResult',
  full_name='google.ads.googleads.v1.services.DismissRecommendationResponse.DismissRecommendationResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.services.DismissRecommendationResponse.DismissRecommendationResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3217,
  serialized_end=3269,
)

_DISMISSRECOMMENDATIONRESPONSE = _descriptor.Descriptor(
  name='DismissRecommendationResponse',
  full_name='google.ads.googleads.v1.services.DismissRecommendationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v1.services.DismissRecommendationResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v1.services.DismissRecommendationResponse.partial_failure_error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DISMISSRECOMMENDATIONRESPONSE_DISMISSRECOMMENDATIONRESULT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3023,
  serialized_end=3269,
)

_APPLYRECOMMENDATIONREQUEST.fields_by_name['operations'].message_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION_CAMPAIGNBUDGETPARAMETERS.fields_by_name['new_budget_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_APPLYRECOMMENDATIONOPERATION_CAMPAIGNBUDGETPARAMETERS.containing_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION_TEXTADPARAMETERS.fields_by_name['ad'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__pb2._AD
_APPLYRECOMMENDATIONOPERATION_TEXTADPARAMETERS.containing_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION_KEYWORDPARAMETERS.fields_by_name['ad_group'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_APPLYRECOMMENDATIONOPERATION_KEYWORDPARAMETERS.fields_by_name['match_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_keyword__match__type__pb2._KEYWORDMATCHTYPEENUM_KEYWORDMATCHTYPE
_APPLYRECOMMENDATIONOPERATION_KEYWORDPARAMETERS.fields_by_name['cpc_bid_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_APPLYRECOMMENDATIONOPERATION_KEYWORDPARAMETERS.containing_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION_TARGETCPAOPTINPARAMETERS.fields_by_name['target_cpa_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_APPLYRECOMMENDATIONOPERATION_TARGETCPAOPTINPARAMETERS.fields_by_name['new_campaign_budget_amount_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_APPLYRECOMMENDATIONOPERATION_TARGETCPAOPTINPARAMETERS.containing_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION_CALLOUTEXTENSIONPARAMETERS.fields_by_name['callout_extensions'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_extensions__pb2._CALLOUTFEEDITEM
_APPLYRECOMMENDATIONOPERATION_CALLOUTEXTENSIONPARAMETERS.containing_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION_CALLEXTENSIONPARAMETERS.fields_by_name['call_extensions'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_extensions__pb2._CALLFEEDITEM
_APPLYRECOMMENDATIONOPERATION_CALLEXTENSIONPARAMETERS.containing_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION_SITELINKEXTENSIONPARAMETERS.fields_by_name['sitelink_extensions'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_extensions__pb2._SITELINKFEEDITEM
_APPLYRECOMMENDATIONOPERATION_SITELINKEXTENSIONPARAMETERS.containing_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION_MOVEUNUSEDBUDGETPARAMETERS.fields_by_name['budget_micros_to_move'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_APPLYRECOMMENDATIONOPERATION_MOVEUNUSEDBUDGETPARAMETERS.containing_type = _APPLYRECOMMENDATIONOPERATION
_APPLYRECOMMENDATIONOPERATION.fields_by_name['campaign_budget'].message_type = _APPLYRECOMMENDATIONOPERATION_CAMPAIGNBUDGETPARAMETERS
_APPLYRECOMMENDATIONOPERATION.fields_by_name['text_ad'].message_type = _APPLYRECOMMENDATIONOPERATION_TEXTADPARAMETERS
_APPLYRECOMMENDATIONOPERATION.fields_by_name['keyword'].message_type = _APPLYRECOMMENDATIONOPERATION_KEYWORDPARAMETERS
_APPLYRECOMMENDATIONOPERATION.fields_by_name['target_cpa_opt_in'].message_type = _APPLYRECOMMENDATIONOPERATION_TARGETCPAOPTINPARAMETERS
_APPLYRECOMMENDATIONOPERATION.fields_by_name['callout_extension'].message_type = _APPLYRECOMMENDATIONOPERATION_CALLOUTEXTENSIONPARAMETERS
_APPLYRECOMMENDATIONOPERATION.fields_by_name['call_extension'].message_type = _APPLYRECOMMENDATIONOPERATION_CALLEXTENSIONPARAMETERS
_APPLYRECOMMENDATIONOPERATION.fields_by_name['sitelink_extension'].message_type = _APPLYRECOMMENDATIONOPERATION_SITELINKEXTENSIONPARAMETERS
_APPLYRECOMMENDATIONOPERATION.fields_by_name['move_unused_budget'].message_type = _APPLYRECOMMENDATIONOPERATION_MOVEUNUSEDBUDGETPARAMETERS
_APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters'].fields.append(
  _APPLYRECOMMENDATIONOPERATION.fields_by_name['campaign_budget'])
_APPLYRECOMMENDATIONOPERATION.fields_by_name['campaign_budget'].containing_oneof = _APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters']
_APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters'].fields.append(
  _APPLYRECOMMENDATIONOPERATION.fields_by_name['text_ad'])
_APPLYRECOMMENDATIONOPERATION.fields_by_name['text_ad'].containing_oneof = _APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters']
_APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters'].fields.append(
  _APPLYRECOMMENDATIONOPERATION.fields_by_name['keyword'])
_APPLYRECOMMENDATIONOPERATION.fields_by_name['keyword'].containing_oneof = _APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters']
_APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters'].fields.append(
  _APPLYRECOMMENDATIONOPERATION.fields_by_name['target_cpa_opt_in'])
_APPLYRECOMMENDATIONOPERATION.fields_by_name['target_cpa_opt_in'].containing_oneof = _APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters']
_APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters'].fields.append(
  _APPLYRECOMMENDATIONOPERATION.fields_by_name['callout_extension'])
_APPLYRECOMMENDATIONOPERATION.fields_by_name['callout_extension'].containing_oneof = _APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters']
_APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters'].fields.append(
  _APPLYRECOMMENDATIONOPERATION.fields_by_name['call_extension'])
_APPLYRECOMMENDATIONOPERATION.fields_by_name['call_extension'].containing_oneof = _APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters']
_APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters'].fields.append(
  _APPLYRECOMMENDATIONOPERATION.fields_by_name['sitelink_extension'])
_APPLYRECOMMENDATIONOPERATION.fields_by_name['sitelink_extension'].containing_oneof = _APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters']
_APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters'].fields.append(
  _APPLYRECOMMENDATIONOPERATION.fields_by_name['move_unused_budget'])
_APPLYRECOMMENDATIONOPERATION.fields_by_name['move_unused_budget'].containing_oneof = _APPLYRECOMMENDATIONOPERATION.oneofs_by_name['apply_parameters']
_APPLYRECOMMENDATIONRESPONSE.fields_by_name['results'].message_type = _APPLYRECOMMENDATIONRESULT
_APPLYRECOMMENDATIONRESPONSE.fields_by_name['partial_failure_error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_DISMISSRECOMMENDATIONREQUEST_DISMISSRECOMMENDATIONOPERATION.containing_type = _DISMISSRECOMMENDATIONREQUEST
_DISMISSRECOMMENDATIONREQUEST.fields_by_name['operations'].message_type = _DISMISSRECOMMENDATIONREQUEST_DISMISSRECOMMENDATIONOPERATION
_DISMISSRECOMMENDATIONRESPONSE_DISMISSRECOMMENDATIONRESULT.containing_type = _DISMISSRECOMMENDATIONRESPONSE
_DISMISSRECOMMENDATIONRESPONSE.fields_by_name['results'].message_type = _DISMISSRECOMMENDATIONRESPONSE_DISMISSRECOMMENDATIONRESULT
_DISMISSRECOMMENDATIONRESPONSE.fields_by_name['partial_failure_error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
DESCRIPTOR.message_types_by_name['GetRecommendationRequest'] = _GETRECOMMENDATIONREQUEST
DESCRIPTOR.message_types_by_name['ApplyRecommendationRequest'] = _APPLYRECOMMENDATIONREQUEST
DESCRIPTOR.message_types_by_name['ApplyRecommendationOperation'] = _APPLYRECOMMENDATIONOPERATION
DESCRIPTOR.message_types_by_name['ApplyRecommendationResponse'] = _APPLYRECOMMENDATIONRESPONSE
DESCRIPTOR.message_types_by_name['ApplyRecommendationResult'] = _APPLYRECOMMENDATIONRESULT
DESCRIPTOR.message_types_by_name['DismissRecommendationRequest'] = _DISMISSRECOMMENDATIONREQUEST
DESCRIPTOR.message_types_by_name['DismissRecommendationResponse'] = _DISMISSRECOMMENDATIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetRecommendationRequest = _reflection.GeneratedProtocolMessageType('GetRecommendationRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETRECOMMENDATIONREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
  ,
  __doc__ = """Request message for
  [RecommendationService.GetRecommendation][google.ads.googleads.v1.services.RecommendationService.GetRecommendation].
  
  
  Attributes:
      resource_name:
          The resource name of the recommendation to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GetRecommendationRequest)
  ))
_sym_db.RegisterMessage(GetRecommendationRequest)

ApplyRecommendationRequest = _reflection.GeneratedProtocolMessageType('ApplyRecommendationRequest', (_message.Message,), dict(
  DESCRIPTOR = _APPLYRECOMMENDATIONREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
  ,
  __doc__ = """Request message for
  [RecommendationService.ApplyRecommendation][google.ads.googleads.v1.services.RecommendationService.ApplyRecommendation].
  
  
  Attributes:
      customer_id:
          The ID of the customer with the recommendation.
      operations:
          The list of operations to apply recommendations. If
          partial\_failure=false all recommendations should be of the
          same type There is a limit of 100 operations per request.
      partial_failure:
          If true, successful operations will be carried out and invalid
          operations will return errors. If false, operations will be
          carried out as a transaction if and only if they are all
          valid. Default is false.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationRequest)
  ))
_sym_db.RegisterMessage(ApplyRecommendationRequest)

ApplyRecommendationOperation = _reflection.GeneratedProtocolMessageType('ApplyRecommendationOperation', (_message.Message,), dict(

  CampaignBudgetParameters = _reflection.GeneratedProtocolMessageType('CampaignBudgetParameters', (_message.Message,), dict(
    DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION_CAMPAIGNBUDGETPARAMETERS,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Parameters to use when applying a campaign budget recommendation.
    
    
    Attributes:
        new_budget_amount_micros:
            New budget amount to set for target budget resource. This is a
            required field.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation.CampaignBudgetParameters)
    ))
  ,

  TextAdParameters = _reflection.GeneratedProtocolMessageType('TextAdParameters', (_message.Message,), dict(
    DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION_TEXTADPARAMETERS,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Parameters to use when applying a text ad recommendation.
    
    
    Attributes:
        ad:
            New ad to add to recommended ad group. All necessary fields
            need to be set in this message. This is a required field.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation.TextAdParameters)
    ))
  ,

  KeywordParameters = _reflection.GeneratedProtocolMessageType('KeywordParameters', (_message.Message,), dict(
    DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION_KEYWORDPARAMETERS,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Parameters to use when applying keyword recommendation.
    
    
    Attributes:
        ad_group:
            The ad group resource to add keyword to. This is a required
            field.
        match_type:
            The match type of the keyword. This is a required field.
        cpc_bid_micros:
            Optional, CPC bid to set for the keyword. If not set, keyword
            will use bid based on bidding strategy used by target ad
            group.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation.KeywordParameters)
    ))
  ,

  TargetCpaOptInParameters = _reflection.GeneratedProtocolMessageType('TargetCpaOptInParameters', (_message.Message,), dict(
    DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION_TARGETCPAOPTINPARAMETERS,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Parameters to use when applying Target CPA recommendation.
    
    
    Attributes:
        target_cpa_micros:
            Average CPA to use for Target CPA bidding strategy. This is a
            required field.
        new_campaign_budget_amount_micros:
            Optional, budget amount to set for the campaign.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation.TargetCpaOptInParameters)
    ))
  ,

  CalloutExtensionParameters = _reflection.GeneratedProtocolMessageType('CalloutExtensionParameters', (_message.Message,), dict(
    DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION_CALLOUTEXTENSIONPARAMETERS,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Parameters to use when applying callout extension recommendation.
    
    
    Attributes:
        callout_extensions:
            Callout extensions to be added. This is a required field.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation.CalloutExtensionParameters)
    ))
  ,

  CallExtensionParameters = _reflection.GeneratedProtocolMessageType('CallExtensionParameters', (_message.Message,), dict(
    DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION_CALLEXTENSIONPARAMETERS,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Parameters to use when applying call extension recommendation.
    
    
    Attributes:
        call_extensions:
            Call extensions to be added. This is a required field.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation.CallExtensionParameters)
    ))
  ,

  SitelinkExtensionParameters = _reflection.GeneratedProtocolMessageType('SitelinkExtensionParameters', (_message.Message,), dict(
    DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION_SITELINKEXTENSIONPARAMETERS,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Parameters to use when applying sitelink extension recommendation.
    
    
    Attributes:
        sitelink_extensions:
            Sitelink extensions to be added. This is a required field.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation.SitelinkExtensionParameters)
    ))
  ,

  MoveUnusedBudgetParameters = _reflection.GeneratedProtocolMessageType('MoveUnusedBudgetParameters', (_message.Message,), dict(
    DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION_MOVEUNUSEDBUDGETPARAMETERS,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Parameters to use when applying move unused budget recommendation.
    
    
    Attributes:
        budget_micros_to_move:
            Budget amount to move from excess budget to constrained
            budget. This is a required field.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation.MoveUnusedBudgetParameters)
    ))
  ,
  DESCRIPTOR = _APPLYRECOMMENDATIONOPERATION,
  __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
  ,
  __doc__ = """Information about the operation to apply a recommendation and any
  parameters to customize it.
  
  
  Attributes:
      resource_name:
          The resource name of the recommendation to apply.
      apply_parameters:
          Parameters to use when applying the recommendation.
      campaign_budget:
          Optional parameters to use when applying a campaign budget
          recommendation.
      text_ad:
          Optional parameters to use when applying a text ad
          recommendation.
      keyword:
          Optional parameters to use when applying keyword
          recommendation.
      target_cpa_opt_in:
          Optional parameters to use when applying target CPA opt-in
          recommendation.
      callout_extension:
          Parameters to use when applying callout extension
          recommendation.
      call_extension:
          Parameters to use when applying call extension recommendation.
      sitelink_extension:
          Parameters to use when applying sitelink extension
          recommendation.
      move_unused_budget:
          Parameters to use when applying move unused budget
          recommendation.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationOperation)
  ))
_sym_db.RegisterMessage(ApplyRecommendationOperation)
_sym_db.RegisterMessage(ApplyRecommendationOperation.CampaignBudgetParameters)
_sym_db.RegisterMessage(ApplyRecommendationOperation.TextAdParameters)
_sym_db.RegisterMessage(ApplyRecommendationOperation.KeywordParameters)
_sym_db.RegisterMessage(ApplyRecommendationOperation.TargetCpaOptInParameters)
_sym_db.RegisterMessage(ApplyRecommendationOperation.CalloutExtensionParameters)
_sym_db.RegisterMessage(ApplyRecommendationOperation.CallExtensionParameters)
_sym_db.RegisterMessage(ApplyRecommendationOperation.SitelinkExtensionParameters)
_sym_db.RegisterMessage(ApplyRecommendationOperation.MoveUnusedBudgetParameters)

ApplyRecommendationResponse = _reflection.GeneratedProtocolMessageType('ApplyRecommendationResponse', (_message.Message,), dict(
  DESCRIPTOR = _APPLYRECOMMENDATIONRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
  ,
  __doc__ = """Response message for
  [RecommendationService.ApplyRecommendation][google.ads.googleads.v1.services.RecommendationService.ApplyRecommendation].
  
  
  Attributes:
      results:
          Results of operations to apply recommendations.
      partial_failure_error:
          Errors that pertain to operation failures in the partial
          failure mode. Returned only when partial\_failure = true and
          all errors occur inside the operations. If any errors occur
          outside the operations (e.g. auth errors) we return the RPC
          level error.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationResponse)
  ))
_sym_db.RegisterMessage(ApplyRecommendationResponse)

ApplyRecommendationResult = _reflection.GeneratedProtocolMessageType('ApplyRecommendationResult', (_message.Message,), dict(
  DESCRIPTOR = _APPLYRECOMMENDATIONRESULT,
  __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
  ,
  __doc__ = """The result of applying a recommendation.
  
  
  Attributes:
      resource_name:
          Returned for successful applies.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ApplyRecommendationResult)
  ))
_sym_db.RegisterMessage(ApplyRecommendationResult)

DismissRecommendationRequest = _reflection.GeneratedProtocolMessageType('DismissRecommendationRequest', (_message.Message,), dict(

  DismissRecommendationOperation = _reflection.GeneratedProtocolMessageType('DismissRecommendationOperation', (_message.Message,), dict(
    DESCRIPTOR = _DISMISSRECOMMENDATIONREQUEST_DISMISSRECOMMENDATIONOPERATION,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """Operation to dismiss a single recommendation identified by
    resource\_name.
    
    
    Attributes:
        resource_name:
            The resource name of the recommendation to dismiss.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.DismissRecommendationRequest.DismissRecommendationOperation)
    ))
  ,
  DESCRIPTOR = _DISMISSRECOMMENDATIONREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
  ,
  __doc__ = """Request message for
  [RecommendationService.DismissRecommendation][google.ads.googleads.v1.services.RecommendationService.DismissRecommendation].
  
  
  Attributes:
      customer_id:
          The ID of the customer with the recommendation.
      operations:
          The list of operations to dismiss recommendations. If
          partial\_failure=false all recommendations should be of the
          same type There is a limit of 100 operations per request.
      partial_failure:
          If true, successful operations will be carried out and invalid
          operations will return errors. If false, operations will be
          carried in a single transaction if and only if they are all
          valid. Default is false.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.DismissRecommendationRequest)
  ))
_sym_db.RegisterMessage(DismissRecommendationRequest)
_sym_db.RegisterMessage(DismissRecommendationRequest.DismissRecommendationOperation)

DismissRecommendationResponse = _reflection.GeneratedProtocolMessageType('DismissRecommendationResponse', (_message.Message,), dict(

  DismissRecommendationResult = _reflection.GeneratedProtocolMessageType('DismissRecommendationResult', (_message.Message,), dict(
    DESCRIPTOR = _DISMISSRECOMMENDATIONRESPONSE_DISMISSRECOMMENDATIONRESULT,
    __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
    ,
    __doc__ = """The result of dismissing a recommendation.
    
    
    Attributes:
        resource_name:
            Returned for successful dismissals.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.DismissRecommendationResponse.DismissRecommendationResult)
    ))
  ,
  DESCRIPTOR = _DISMISSRECOMMENDATIONRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.recommendation_service_pb2'
  ,
  __doc__ = """Response message for
  [RecommendationService.DismissRecommendation][google.ads.googleads.v1.services.RecommendationService.DismissRecommendation].
  
  
  Attributes:
      results:
          Results of operations to dismiss recommendations.
      partial_failure_error:
          Errors that pertain to operation failures in the partial
          failure mode. Returned only when partial\_failure = true and
          all errors occur inside the operations. If any errors occur
          outside the operations (e.g. auth errors) we return the RPC
          level error.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.DismissRecommendationResponse)
  ))
_sym_db.RegisterMessage(DismissRecommendationResponse)
_sym_db.RegisterMessage(DismissRecommendationResponse.DismissRecommendationResult)


DESCRIPTOR._options = None

_RECOMMENDATIONSERVICE = _descriptor.ServiceDescriptor(
  name='RecommendationService',
  full_name='google.ads.googleads.v1.services.RecommendationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=3272,
  serialized_end=3921,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetRecommendation',
    full_name='google.ads.googleads.v1.services.RecommendationService.GetRecommendation',
    index=0,
    containing_service=None,
    input_type=_GETRECOMMENDATIONREQUEST,
    output_type=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_recommendation__pb2._RECOMMENDATION,
    serialized_options=_b('\202\323\344\223\0023\0221/v1/{resource_name=customers/*/recommendations/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='ApplyRecommendation',
    full_name='google.ads.googleads.v1.services.RecommendationService.ApplyRecommendation',
    index=1,
    containing_service=None,
    input_type=_APPLYRECOMMENDATIONREQUEST,
    output_type=_APPLYRECOMMENDATIONRESPONSE,
    serialized_options=_b('\202\323\344\223\0028\"3/v1/customers/{customer_id=*}/recommendations:apply:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='DismissRecommendation',
    full_name='google.ads.googleads.v1.services.RecommendationService.DismissRecommendation',
    index=2,
    containing_service=None,
    input_type=_DISMISSRECOMMENDATIONREQUEST,
    output_type=_DISMISSRECOMMENDATIONRESPONSE,
    serialized_options=_b('\202\323\344\223\002:\"5/v1/customers/{customer_id=*}/recommendations:dismiss:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_RECOMMENDATIONSERVICE)

DESCRIPTOR.services_by_name['RecommendationService'] = _RECOMMENDATIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/dynamic_search_ads_search_term_view.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/dynamic_search_ads_search_term_view.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB#DynamicSearchAdsSearchTermViewProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\nQgoogle/ads/googleads_v2/proto/resources/dynamic_search_ads_search_term_view.proto\x12!google.ads.googleads.v2.resources\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xfe\x01\n\x1e\x44ynamicSearchAdsSearchTermView\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\x31\n\x0bsearch_term\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08headline\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0clanding_page\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08page_url\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x90\x02\n%com.google.ads.googleads.v2.resourcesB#DynamicSearchAdsSearchTermViewProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_DYNAMICSEARCHADSSEARCHTERMVIEW = _descriptor.Descriptor(
  name='DynamicSearchAdsSearchTermView',
  full_name='google.ads.googleads.v2.resources.DynamicSearchAdsSearchTermView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.DynamicSearchAdsSearchTermView.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='search_term', full_name='google.ads.googleads.v2.resources.DynamicSearchAdsSearchTermView.search_term', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headline', full_name='google.ads.googleads.v2.resources.DynamicSearchAdsSearchTermView.headline', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='landing_page', full_name='google.ads.googleads.v2.resources.DynamicSearchAdsSearchTermView.landing_page', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_url', full_name='google.ads.googleads.v2.resources.DynamicSearchAdsSearchTermView.page_url', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=183,
  serialized_end=437,
)

_DYNAMICSEARCHADSSEARCHTERMVIEW.fields_by_name['search_term'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DYNAMICSEARCHADSSEARCHTERMVIEW.fields_by_name['headline'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DYNAMICSEARCHADSSEARCHTERMVIEW.fields_by_name['landing_page'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DYNAMICSEARCHADSSEARCHTERMVIEW.fields_by_name['page_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['DynamicSearchAdsSearchTermView'] = _DYNAMICSEARCHADSSEARCHTERMVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DynamicSearchAdsSearchTermView = _reflection.GeneratedProtocolMessageType('DynamicSearchAdsSearchTermView', (_message.Message,), dict(
  DESCRIPTOR = _DYNAMICSEARCHADSSEARCHTERMVIEW,
  __module__ = 'google.ads.googleads_v2.proto.resources.dynamic_search_ads_search_term_view_pb2'
  ,
  __doc__ = """A dynamic search ads search term view.
  
  
  Attributes:
      resource_name:
          The resource name of the dynamic search ads search term view.
          Dynamic search ads search term view resource names have the
          form:  ``customers/{customer_id}/dynamicSearchAdsSearchTermVie
          ws/{ad_group_id}~{search_term_fp}~{headline_fp}~{landing_page_
          fp}~{page_url_fp}``
      search_term:
          Search term  This field is read-only.
      headline:
          The dynamically generated headline of the Dynamic Search Ad.
          This field is read-only.
      landing_page:
          The dynamically selected landing page URL of the impression.
          This field is read-only.
      page_url:
          The URL of page feed item served for the impression.  This
          field is read-only.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.DynamicSearchAdsSearchTermView)
  ))
_sym_db.RegisterMessage(DynamicSearchAdsSearchTermView)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.resources import ad_parameter_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__parameter__pb2
from google.ads.google_ads.v1.proto.services import ad_parameter_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_ad__parameter__service__pb2


class AdParameterServiceStub(object):
  """Proto file describing the Ad Parameter service.

  Service to manage ad parameters.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetAdParameter = channel.unary_unary(
        '/google.ads.googleads.v1.services.AdParameterService/GetAdParameter',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_ad__parameter__service__pb2.GetAdParameterRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__parameter__pb2.AdParameter.FromString,
        )
    self.MutateAdParameters = channel.unary_unary(
        '/google.ads.googleads.v1.services.AdParameterService/MutateAdParameters',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_ad__parameter__service__pb2.MutateAdParametersRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_ad__parameter__service__pb2.MutateAdParametersResponse.FromString,
        )


class AdParameterServiceServicer(object):
  """Proto file describing the Ad Parameter service.

  Service to manage ad parameters.
  """

  def GetAdParameter(self, request, context):
    """Returns the requested ad parameter in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateAdParameters(self, request, context):
    """Creates, updates, or removes ad parameters. Operation statuses are
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AdParameterServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetAdParameter': grpc.unary_unary_rpc_method_handler(
          servicer.GetAdParameter,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_ad__parameter__service__pb2.GetAdParameterRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_ad__parameter__pb2.AdParameter.SerializeToString,
      ),
      'MutateAdParameters': grpc.unary_unary_rpc_method_handler(
          servicer.MutateAdParameters,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_ad__parameter__service__pb2.MutateAdParametersRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_ad__parameter__service__pb2.MutateAdParametersResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.AdParameterService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v1.proto.resources import shared_set_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_shared__set__pb2
from google.ads.google_ads.v1.proto.services import shared_set_service_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_shared__set__service__pb2


class SharedSetServiceStub(object):
  """Proto file describing the Shared Set service.

  Service to manage shared sets.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetSharedSet = channel.unary_unary(
        '/google.ads.googleads.v1.services.SharedSetService/GetSharedSet',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_shared__set__service__pb2.GetSharedSetRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_shared__set__pb2.SharedSet.FromString,
        )
    self.MutateSharedSets = channel.unary_unary(
        '/google.ads.googleads.v1.services.SharedSetService/MutateSharedSets',
        request_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_shared__set__service__pb2.MutateSharedSetsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_shared__set__service__pb2.MutateSharedSetsResponse.FromString,
        )


class SharedSetServiceServicer(object):
  """Proto file describing the Shared Set service.

  Service to manage shared sets.
  """

  def GetSharedSet(self, request, context):
    """Returns the requested shared set in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateSharedSets(self, request, context):
    """Creates, updates, or removes shared sets. Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SharedSetServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetSharedSet': grpc.unary_unary_rpc_method_handler(
          servicer.GetSharedSet,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_shared__set__service__pb2.GetSharedSetRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_resources_dot_shared__set__pb2.SharedSet.SerializeToString,
      ),
      'MutateSharedSets': grpc.unary_unary_rpc_method_handler(
          servicer.MutateSharedSets,
          request_deserializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_shared__set__service__pb2.MutateSharedSetsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v1_dot_proto_dot_services_dot_shared__set__service__pb2.MutateSharedSetsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v1.services.SharedSetService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
